==> zen-cortex-8.1.1.tgz: package/actions/selection.js <==
import { api } from "zen-cerebellum";

import { browseTo } from "./router";
import { SEND_ENTITIES } from "../constants";
import { getId, getKind, isShare } from "../utils/core";

/** WAA - Send a entities selection query
 * @param {object} selection : generic ZEN SelectionDto
 */
function sendSelection(selection) {
  return api.post(SEND_ENTITIES, "/selection", selection);
}

/**
 * Enhance action handler with multiple selection behavior
 * @param {func} actionHandler - Action handler using backend GUID
 * @param {hash} - configuration option :
 *  @param {string} open - Name of open action
 *  @param {bool} noShare - True to use targeted entity instead of share itself
 */
export function withMultiSelection(
  actionHandler,
  { open = null, noShare = false } = {}
) {
  /**
   * Wraps the multi-selection handler with:
   * @param {array} entities - list of heterogeneous entities
   * @returns chained WAA
   */
  return function(entities) {
    return (dispatch, getState) => {
      //first, save selected entities
      return dispatch(
        sendSelection({ entities: selectify(entities, noShare) })
      ).then(
        //next, dispatch mutli-action from handler using received selection cached key
        selectionKey => {
          if (open) {
            //case open action
            const url = actionHandler(selectionKey, open, getState());
            if (url) return browseTo(url);
          } else {
            //case dispatch action (but keep track of original entities selection)
            return dispatch({
              ...actionHandler(selectionKey),
              meta: {
                entities
              }
            });
          }
        }
      );
    };
  };
}

/**
 * Transform a list of entities into a ZEN selection.
 * @param {array} entities - list of heterogeneous entities
 * @param {bool} [noShare] - True to flat shares
 * @return {array} ZEN generic selection
 */
export function selectify(entities, noShare = false) {
  return entities.map(e => {
    const share = isShare(e);
    const TargetKind = getKind(e);

    return {
      Kind: noShare ? TargetKind : e.Kind,
      TargetId: getId(e),
      TargetKind,
      LocId: share && !noShare ? e.LocId : undefined,
      LocKind: share && !noShare ? e.LocKind : undefined
    };
  });
}

==> zen-cortex-8.3.0.tgz: package/actions/selection.js <==
import { api } from "zen-cerebellum";

import { browseTo } from "./router";
import { SEND_ENTITIES } from "../constants";
import { getId, getKind, isShare } from "../utils/core";

/** WAA - Send a entities selection query
 * @param {object} selection : generic ZEN SelectionDto
 */
function sendSelection(selection) {
  return api.post(SEND_ENTITIES, "/selection", selection);
}

/**
 * Enhance action handler with multiple selection behavior
 * @param {func} actionHandler - Action handler using backend GUID
 * @param {hash} - configuration option :
 *  @param {string} open - Name of open action
 *  @param {bool} noShare - True to use targeted entity instead of share itself
 */
export function withMultiSelection(
  actionHandler,
  { open = null, noShare = false } = {}
) {
  /**
   * Wraps the multi-selection handler with:
   * @param {array} entities - list of heterogeneous entities
   * @returns chained WAA
   */
  return function(entities) {
    return (dispatch, getState) => {
      //first, save selected entities
      return dispatch(
        sendSelection({ entities: entities.map(e => selectify(e, noShare)) })
      ).then(
        //next, dispatch multi-action from handler using received selection cached key
        selectionKey => {
          if (open) {
            //case open action
            const url = actionHandler(selectionKey, open, getState());
            if (url) return browseTo(url);
          } else {
            //case dispatch action (but keep track of original entities selection)
            return dispatch({
              ...actionHandler(selectionKey),
              meta: {
                entities
              }
            });
          }
        }
      );
    };
  };
}

/**
 * Transform an entity into a ZEN generic representation.
 * @param {object} entity - heterogeneous entity
 * @param {bool} [noShare] - True to crunch shares
 * @return {object} ZEN generic item
 */
export function selectify(entity, noShare = false) {
  const share = isShare(entity);
  const TargetKind = getKind(entity);

  return {
    Kind: noShare ? TargetKind : entity.Kind,
    TargetId: getId(entity),
    TargetKind,
    LocId: share && !noShare ? entity.LocId : undefined,
    LocKind: share && !noShare ? entity.LocKind : undefined
  };
}
